@@ -22,12 +22,13 @@ def write_json_file(data, file_path):
 def bump_version(file_path, position):
   package_json = read_json_file(file_path)
   version = package_json["version"]
+  name = package_json["name"]
   arr = version.split(".")
   arr[position] = str(int(arr[position]) + 1)
   new_version = ".".join(arr)
   package_json["version"] = new_version
   write_json_file(package_json, file_path)
-  return new_version
+  return name, new_version
 
 def bump_major(file_path):
     return bump_version(file_path, 0)
